<?php

namespace Drupal\noreferrer\Hook;

use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Implements hook_help().
 */
#[Hook('help')]
class Help {

  use StringTranslationTrait;

  /**
   * Implements hook_help().
   *
   * @return array<array<string|TranslatableMarkup>>|TranslatableMarkup
   *   The help array.
   */
  public function __invoke(?string $route_name): TranslatableMarkup|array {
    switch ($route_name) {
      case 'help.page.noreferrer':
        // Generate two paragraphs.
        $output = array_fill(0, 2, ['#type' => 'html_tag', '#tag' => 'p']);
        $output[0]['#value'] = $this->t('No Referrer module allows you to add <code>referrerpolicy="no-referrer"</code>, <code>rel="noopener"</code> and/or <code>rel="noreferrer"</code> to user-generated content and external links generated by code.');
        $output[1]['#value'] = $this->t('To apply the configured attributes to user-generated content, simply enable the <em>Add referrerpolicy="no-referrer", rel="noopener" and/or rel="noreferrer"</em> filter on your text formats.');
        return $output;

      case 'noreferrer.settings':
        return $this->t('The attributes enabled below will be added to user-generated content using the <em>Add referrerpolicy="no-referrer", rel="noopener" and/or rel="noreferrer"</em> filter. The <code>rel</code> attributes will also be added to links generated by code, such as link fields and menu items.');
    }
    return [];
  }

}
